@@ -1,5 +1,3 @@
-# Author:  Lisandro Dalcin
-# Contact: dalcinl@gmail.com
 import os
 import sys
 import optparse
@@ -182,7 +180,7 @@ def load_tests(options, args):
     testsuite = unittest.TestSuite()
     testloader = unittest.TestLoader()
     if options.patterns:
-        testloader.testNamePatterns = [
+        testloader.testNamePatterns = [ # novermin
             ('*%s*' % p) if ('*' not in p) else p
             for p in options.patterns
         ]
